/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Initial Developer of the Original Code is Soyapi Mumba.
 *
 * Portions created by the Initial Developer are Copyright (C) 2005,2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
 
var SWOptions = {

	swServiceList: null,
	swEngineList: null,
	swNewEngineList: null,
	swPluginDirList: null,
	prefs: null,
	swPrefs: null, 
	svcPrefs: null,
	swPrefsString: "extensions.searchwith.",

    onLoad: function() 
    {
        this.prefs = Components.classes["@mozilla.org/preferences-service;1"].
                    getService(Components.interfaces.nsIPrefService);  
        this.swPrefs = this.prefs.getBranch("extensions.searchwith.");
        
        this.swServiceList = document.getElementById("searchwith-prefs-service-list");
        this.swEngineList = document.getElementById("searchwith-prefs-engine-list");
        this.swNewEngineList = document.getElementById("searchwith-prefs-new-service-engine");
        
        this.populateServices();
        this.swServiceList.selectItem(this.swServiceList.getItemAtIndex(0));
        
        this.populateEngines();
        this.swEngineList.selectItem(this.swEngineList.getItemAtIndex(0));
		
		this.populatePluginDirs();
        
        var enableContextMenu = document.getElementById("searchwith-prefs-enable-context");
        enableContextMenu.checked = SearchWith.getBoolPref("enable-contextmenu");
		//centerWindowOnScreen();
    },
    
    addService: function() 
    {
        var newServiceName = "";
        var newServiceId = "";
        
        newServiceName = document.getElementById("searchwith-prefs-new-service").value;
        newServiceName.trim();
        if (newServiceName.length <1) {
            return;
        }
        
        newServiceId = SearchWith.createId(newServiceName);
        var tmpService = new SWService(newServiceId);
		tmpService.addToList();
		
		if (tmpService.getName().length >0) {
            alert(SearchWith.getPropString("service.already.exists", "searchwith-strings"));
            return;
        }
              
        var li = this.swServiceList.appendItem(newServiceName, newServiceId);
        li.disabled = true;
    
        this.swServiceList.selectedItem = li;
        document.getElementById("searchwith-prefs-new-service").value = "";
        this.editService();
    }, 
    
    populateServices: function() 
    {
        var serviceName = "";
        var swServices = SearchWith.getServices();
        this.swServiceList = document.getElementById("searchwith-prefs-service-list");
         
        SearchWith.removeChildren(this.swServiceList);
        
        for (each in swServices) {
            var aService = new SWService(swServices[each]);
            if (swServices[each].trim().length>0 && 
			    aService.getName().trim().length>0) {
                var aListItem = this.swServiceList.appendItem(aService.getName(), 
                                                        swServices[each]);
                if (!aService.isEnabled()) {
                    aListItem.disabled = true;
                }
            }
        }
    },
    
    populateEngines: function() 
    {
        var swEngines = SearchWith.getEngines();
        SearchWith.removeChildren(this.swEngineList);
        for (each in swEngines) {
            var anEngine = new SWEngine(swEngines[each]);
            if (swEngines[each].trim().length >0 && 
			    anEngine.getName().trim().length>0) {
                this.swEngineList.appendItem(anEngine.getName(), swEngines[each]);
            }
        }
    },
    
	populatePluginDirs: function() 
    {
        var swPluginDirs = SearchWith.getCVPref("pluginsDirList").split(",");
        this.swPluginDirList = document.getElementById("searchwith-prefs-plugin-dirlist");
         
        SearchWith.removeChildren(this.swPluginDirList);
        
        for (each in swPluginDirs) {
			var aListItem = this.swPluginDirList.appendItem(swPluginDirs[each], 
													swPluginDirs[each].toLowerCase());
			//aListItem.tooltiptext = swPluginDirs[each];
			aListItem.setAttribute("tooltiptext", swPluginDirs[each]);
			aListItem.crop = "center";
        }
    },
	
    editService: function() 
    {
        var swsl = document.getElementById("searchwith-prefs-service-list");
        window.openDialog("chrome://searchwith/content/swOptionsService.xul",
							"Service Options", "chrome", swsl);
    },
    
    removeService: function() 
    {
        var swsl = this.swServiceList;
		var delWarn = "";
		try {
            var strBundle = document.getElementById("searchwith-strings");
            delWarn = strBundle.getFormattedString("permanently.delete.service", 
													[swsl.selectedItem.label]);
        } catch(e) {
            delWarn = "permanently.delete.service";
        }
        if (!confirm(delWarn)) {
            return;
        }
		
        var serviceId = swsl.selectedItem.value;
        
        var swServices = SearchWith.getServices();
        var arr = new Array();
        for (each in swServices) {
            if (swServices[each] != serviceId) {
                arr.push(swServices[each]);
            }
        }
        
        var suppStr = Components.classes["@mozilla.org/supports-string;1"].createInstance(
									Components.interfaces.nsISupportsString);
        suppStr.data = arr.join(",");
        try {
            this.swPrefs.setComplexValue("service-list",
                                Components.interfaces.nsISupportsString, suppStr);
            this.swPrefs.deleteBranch("service."+serviceId);                    
        } catch(e) {
        }
        
        swsl.removeItemAt(swsl.getIndexOfItem(swsl.selectedItem));
    },
    
    addEngine: function() 
    {
        var newEngineName = "";
        var newEngineId = "";
    
        newEngineName = document.getElementById("searchwith-prefs-new-engine").value;
        newEngineName = newEngineName.trim();
        if (newEngineName.length <1) {
            return;
        }
        
        newEngineId = SearchWith.createId(newEngineName);
        var newEngine = new SWEngine(newEngineId);
        if (newEngine.getName().length > 0) {
            alert(SearchWith.getPropString("engine.already.exists", "searchwith-strings"));
        }
        
        newEngine.addToList();
        
        newEngine.setName(newEngineName);
        var eli = this.swEngineList.appendItem(newEngineName, newEngineId);
        this.swEngineList.selectedItem = eli;
        document.getElementById("searchwith-prefs-new-engine").value = "";
        this.editEngine();
    },
    
    editEngine: function() 
    {
        var swel = document.getElementById("searchwith-prefs-engine-list");;
        window.openDialog("chrome://searchwith/content/swOptionsEngine.xul","Edit Engine",
                      "chrome",swel);
    },
    
    removeEngine: function() 
    {
        var swel = this.swEngineList;
        var engineId = swel.selectedItem.value;
        var delWarn = "";
		try {
            var strBundle = document.getElementById("searchwith-strings");
            delWarn = strBundle.getFormattedString("permanently.delete.engine", 
													[swel.selectedItem.label]);
        } catch(e) {
            delWarn = "permanently.delete.engine";
        }
        if (!confirm(delWarn)) {
            return;
        }
        
        // if engine to be deleted is being used by a search service, disable the service
        var swServices = SearchWith.getServices();
        for (each in swServices) {
            var aService = new SWService(swServices[each]);
            if (aService.getEngineId() == swel.selectedItem.value) {
                aService.setEngineId("");
            }
        }
            
                
        var swEngines = SearchWith.getEngines();
        var arr = new Array();
        for (each in swEngines) {
            if (swEngines[each] != engineId) {
                arr.push(swEngines[each]);
            }
        }

        var suppStr = Components.classes["@mozilla.org/supports-string;1"].createInstance(
									Components.interfaces.nsISupportsString);
        suppStr.data = arr.join(",");
        try {
            this.swPrefs.setComplexValue("engine-list",
                                Components.interfaces.nsISupportsString, suppStr);
        } catch(e) {
        }
        
        try {
            //this.swPrefs.deleteBranch("engine-list."+swel.selectedItem.value);
            this.swPrefs.deleteBranch("engine."+swel.selectedItem.value);
            //swel.removeItemAt(swel.getIndexOfItem(swel.selectedItem)); 
        } catch(e) {
        }
        swel.removeItemAt(swel.getIndexOfItem(swel.selectedItem));
        this.populateServices();
        this.populateEngines();
    },
    
    checkAddServiceBtn: function() 
    {
        var newService = document.getElementById("searchwith-prefs-new-service").value;
        newService = newService.trim();
        if (newService.length <1) {
            document.getElementById("searchwith-prefs-add-service-button").disabled = true;
        } else {
            document.getElementById("searchwith-prefs-add-service-button").disabled = false;
        }
    },
    
    checkAddEngineBtn: function() 
    {
        var newEngine = document.getElementById("searchwith-prefs-new-engine").value;
        newEngine = newEngine.replace(/\s+/g,'');
        if (newEngine.length <1) {
            document.getElementById("searchwith-prefs-add-engine-button").disabled = true;
        } else {
            document.getElementById("searchwith-prefs-add-engine-button").disabled = false;
        }
    },
    
    restoreDefaults: function() 
    {
        var swel = this.swEngineList;
        if (!confirm(SearchWith.getPropString("restore.default.settings", "searchwith-strings"))) {
            return;
        }
		
		SearchWith.resetSettings();
		//SearchWith.importSearchBarEngines();
        SearchWith.doFirstRun();
        this.populateServices();
        this.populateEngines();
		this.populatePluginDirs();
    },
    
    loadMycroftPlugins: function() 
	{    
        SearchWith.importSearchBarEngines();
        this.populateEngines();
    },
    
    moveService: function(aDirection)
    {
        var swsl = this.swServiceList;
        var serviceId = swsl.selectedItem.value;
        var swServices = SearchWith.getServices();
        
        var itemPos = swsl.selectedIndex;
        var newPos = 0;
        
        if (aDirection == "up") {
            if (itemPos > 0) {
                newPos = itemPos-1;
                swServices[itemPos] = swServices[newPos];
                swServices[newPos] = serviceId;
            }
        } else {
            if (itemPos < swServices.length) {
                newPos = itemPos+1;
                swServices[itemPos] = swServices[newPos];
                swServices[newPos] = serviceId;
            }
        }
        
        var suppStr = Components.classes["@mozilla.org/supports-string;1"].createInstance(
									Components.interfaces.nsISupportsString);
        suppStr.data = swServices.join(",");
        
        try {
            this.swPrefs.setComplexValue("service-list",
                                Components.interfaces.nsISupportsString, suppStr);
        } catch(e) {
        }
        
        this.populateServices();
        swsl.selectedIndex = newPos;
    },
    
    addDir: function() 
    {
		var newPath = document.getElementById("searchwith-prefs-new-plugindir").value.trim();
		if (newPath.length < 1) {
			newPath = SearchWith.browse4Dir();
		}
		if (newPath.length>0) {
			this.swPluginDirList = document.getElementById("searchwith-prefs-plugin-dirlist");
			var newItem = this.swPluginDirList.appendItem(newPath, newPath.toLowerCase());
            
            var currDirs = SearchWith.getCVPref("pluginsDirList").split(",");
            currDirs.push(newPath);
            SearchWith.setCVPref("pluginsDirList", currDirs.join(","));
		}
        
    },
	
	removePluginDir: function()
	{
		var currDirs = SearchWith.getCVPref("pluginsDirList").split(",");
		this.swPluginDirList = document.getElementById("searchwith-prefs-plugin-dirlist");
		var newDirs = new Array();
		for (each in currDirs) {
			if (currDirs[each].toLowerCase() != this.swPluginDirList.selectedItem.value.toLowerCase()) {
				newDirs.push(currDirs[each]);
			}
		}

		SearchWith.setCVPref("pluginsDirList", newDirs.join(","));
		this.swPluginDirList.removeItemAt(this.swPluginDirList.selectedIndex);
	},
    
    changeShowContext: function()
    {
        var currVal = document.getElementById("searchwith-prefs-enable-context").checked;
        SearchWith.setBoolPref("enable-contextmenu", currVal);
    }
    
};
